#
# spec file for package python-Faker
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define oldpython python
Name:           python-Faker
Version:        3.0.1
Release:        bp154.1.18
Summary:        Python package that generates fake data
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/joke2k/faker
Source:         https://files.pythonhosted.org/packages/source/F/Faker/Faker-%{version}.tar.gz
BuildRequires:  %{python_module UkPostcodeParser >= 1.1.1}
BuildRequires:  %{python_module freezegun}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module pytest >= 3.8.0}
BuildRequires:  %{python_module pytest-runner}
BuildRequires:  %{python_module python-dateutil >= 2.4}
BuildRequires:  %{python_module random2}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six >= 1.10}
BuildRequires:  %{python_module text-unidecode >= 1.3}
BuildRequires:  %{python_module validators >= 0.13.0}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python2-ipaddress
Requires:       python-python-dateutil >= 2.4
Requires:       python-setuptools
Requires:       python-six >= 1.10
Requires:       python-text-unidecode >= 1.3
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%ifpython2
Requires:       python2-ipaddress
Obsoletes:      %{oldpython}-fake-factory < %{version}
Provides:       %{oldpython}-fake-factory = %{version}
%endif
%ifpython3
Obsoletes:      python3-fake-factory < %{version}
Provides:       python3-fake-factory = %{version}
%endif
%python_subpackages

%description
Faker is a Python package that generates fake data. It helps with
database bootstrapping, creating XML documents, persistence stress
testing, and data anonymization from production services.

%prep
%setup -q -n Faker-%{version}
# Remove pre-existing bytecode files in the sdist
find . -name '*.py[co]' -delete
# do not hardcode versions
sed -i -e 's:"pytest>=3.8.0,<3.9":"pytest>=3.8.0":g' setup.py
sed -i -e 's:==:>=:g' setup.py

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/faker
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative faker

%postun
%python_uninstall_alternative faker

%check
%pytest

%files %{python_files}
%license LICENSE.txt
%doc CHANGELOG.rst README.rst
%python_alternative %{_bindir}/faker
%{python_sitelib}/*

%changelog
* Fri Jan 17 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.0.1:
  * Add provider methods zip and tar for generating zip and tar files. Thanks @malefice.
  * Add en-CA postcode_in_province() method. Thanks @oeuftete.
  * Update Address and Automotive provider for Russian locale. Thanks @valestel.
  * Add provider methods for dsv files: csv, tsv, psv and generic dsv. Thanks @malefice.
  * Remove parenthesis from city name in de_DE address provider. Thanks @jerr0328.
  * Add NIP generator in pl_PL. Thanks @IlfirinPL.
  * Fix Faker.random_number intermittent exceptions. Thanks @Jengah.
* Mon Jan 13 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 3.0.0
  * Breaking change: Add support for multiple locale data generation.
  * Add Iranian credit card.
  * Improve color provider.
  * Drop python 3.4.
  * Fix master card number generator.
  * Add provider for Finnish IBAN numbers.
  * Split first names into male/female for person/de_AT.
  * Optimize IPv4 address generation.
  * Add support for token-based string generation.
  * Use the provider's RNG instead of the random module in invalid_ssn.
  * More small fixes.
* Tue Sep 24 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.0.2:
  * Add nationalities for locale pt_PT. Thanks @tng10.
  * Add ios() and android() to user_agent provider. Thanks @gsilvan.
  * Update zh_CN provinces. Thanks @casen27.
  * Fix typos, misspellings. Add locations, names, dates in hi_IN providers. Thanks @kathawala.
  * Bump required version text-unidecode to 1.3. Thanks @moggers87.
  * Bug fix for pyfloat going over max_value. Thanks @fgs-dbudwin.
* Wed Jul 24 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 2.0.0
  * Breaking change: Only allow providers to use OrderedDict s, to
    avoid any more PYTHONHASHSEED problems.
  * Remove some validations from Faker and delegate it to an
    external library, validators.
  * Add an "Invalid SSN" generator to the en_US SSN Provider.
  * Loosen version restrictions on freezegun and random2.
  * Add date_of_birth and sex argument to pesel Provider (pl_PL).
  * Fix datetime parsing on environments with negative offsets.
* Fri Jul 19 2019 Sean Marlow <sean.marlow@suse.com>
- Update ipaddress requirements.
* Thu May 23 2019 pgajdos@suse.com
- version update to 1.0.7
  * Remove dead url from ``image_placeholder_services``. Thanks @Monstrofil.
  * Fix missing ``first_names`` in Romanian person provider. Thanks @xlotlu.
  * Add Catalan, adds doi/nie/nif/cif to Spain ssn. Thanks @kingbuzzman.
  * Add ``texts`` to generate list of texts. Thanks @pishchalnikov.
  * Add provider for ``pl_PL`` automotive and Polish pesel number. Thanks @adwojak.
  * Corrected behavior for ``pyfloat``. Thanks @ariksu.
  * Add missing commas to company/nl_NL provider. Thanks @francoisfreitag.
  * Add bounds to ``pyint``. Thanks @francoisfreitag.
  * Accept step argument in ``random_int()``. Thanks @francoisfreitag.
* Fri Apr 26 2019 pgajdos@suse.com
- version update to 1.0.5
  * Add min and max values for ``pyfloat`` and ``pydecimal``.
    Thanks @Lrcezimbra.
  * Add ``months`` and ``M`` to the syntax for ``start_date`` and
    ``end_date``. Thanks @anneclairebrld.
  * Add support for ``PyInstaller``. Thanks @arossert.
  * Add Dutch company names. Thanks @MathynS.
  * Fix some invalid French phone numbers starting with ``+33 8x``.
    Thanks @stephane.
  * Add Armenian locale ``hy_AM``. Thanks @hovikman.
- deleted patches
  - ipaddress.patch (upstreamed)
* Fri Mar 15 2019 Jan Engelhardt <jengelh@inai.de>
- Trim duplicated name from summary.
* Fri Mar 15 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch ipaddress.patch to fix its runtime detection
* Thu Mar 14 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.0.4:
  * Various small fixes, see CHANGELOG.rst
- Merge patch faker-32bit.patch
* Tue Mar 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to fix 32bit builds:
  * faker-32bit.patch
* Sun Mar 10 2019 John Vandenberg <jayvdb@gmail.com>
- Remove pre-existing bytecode files in the sdist, which were
  being included in the runtime package and causing lint warnings
  on Leap 42.3 & SLE 12 SP4, and they were breaking tests on Leap 15.
* Thu Feb 14 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.0.2:
  * Many changes to list see CHANGELOG.rst
- Run tests
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Jan 17 2018 arun@gmx.de
- specfile:
  * update copyright year
- update to version 0.8.10:
  * Pass python_requires argument to setuptools. Thanks @jdufresne.
  * Remove some words from en_US lorem ipsum provider. Thanks @Pomax.
- changes from version 0.8.9:
  * Remove support for Python 3.3. Thanks @jdufresne.
  * Allow past dates within a second. Thanks @DanEEstar.
  * Added phone number formatting to en_GB localisation to ensure no
    genuine phone numbers are generated. Thanks @TheSapper.
  * Added en_GB localisation for SSN (UK National Insurance
    Number). Thanks @TheSapper.
  * Added ro_RO person Provider. Thanks @vasilesmartup.
  * Added domain argument to email provider. Thanks @lcd1232.
* Thu Dec 21 2017 arun@gmx.de
- update to version 0.8.8:
  * made seed_instance return self for chainability.
  * Add en_US locale for lorem. Thanks @shacker.
  * fi_FI gender specific data added. Thanks @mikkhola.
  * fi_FI address and job lists updated. Thanks @mikkhola.
  * Add iban provider. Thanks @cdaller.
* Wed Nov 15 2017 arun@gmx.de
- update to version 0.8.7:
  * Corrected some issues with the Hungarian (hu_HU) providers, such
    as incorrectly capitalized company suffixes, street/road type
    names and place names. Thanks @chrisvoncsefalvay.
  * The Hungarian locale's providers.job.job provider now returns
    Hungarian job names, taken from the Hungarian National Statistical
    Office (KSH)'s 2008 survey nomenclature of employment (FEOR
    '08). Thanks @chrisvoncsefalvay.
  * Added he_IL locale. Thanks @bjesus.
  * Fix possible infinite loop in random_sample_unique. Thanks
    @153957.
  * Add aliases to make pt_BR address provider compatible with
    en_US. Thanks @diegoholiveira.
  * Fix ResourceWarning in setup.py. Thanks @jdufresne.
  * Update test requirements.
* Sun Oct 22 2017 arun@gmx.de
- specfile:
  * added requirement for text-unidecode
- update to version 0.8.6:
  * Replace unidecode dependency in favor of text-unidecode. Faker now
    requires text-unidecode.
- changes from version 0.8.5:
  * Add ASCII emails. Thanks @barseghyanartur.
  * Add id_ID Providers. Thanks Sidi Ahmad.
  * Fix date_time.time_series() to ensure start and end bounds are
    inclusive. Thanks @bijanvakili.
  * Create a provider to Brazilian license plates. Thanks
    @diegoholiveira.
  * Use a proper international format for Ukrainian phone
    numbers. Thanks @illia-v.
  * Faker now requires Unidecode.
- changes from version 0.8.4:
  * Move email_validator to test_requires and unpinned the version
    number.
  * Date feature parity with datetime. Thanks @noirbizarre.
  * Add MSISDN in the phone_number provider. Thanks @patrickporto.
  * Add Arabic locales. Thanks @ahmedaljazzar.
  * Fix datetime issue on Windows. Thanks @kungfu71186.
* Mon Sep 11 2017 jengelh@inai.de
- Rewrite description to focus on the package.
* Wed Sep  6 2017 toddrme2178@gmail.com
- Initial version
